@@ -601,8 +601,6 @@ class TurkuImporter(Importer):
                 addr = street.addrs.get(addr_id, None)
                 location = convert_from_gk23(coord_n, coord_e)# Old code conversion uses ETRS-GK25 (Helsinki region). NOTE! Check the result
                 #addr.location = location.wkb
-                addr.location = location
-                addr.save()
                 #print("New addr.location... ", addr.location)
                 #addr.save() # force save address...
                 #print(street, addr, location)
@@ -611,9 +609,11 @@ class TurkuImporter(Importer):
                     self.logger.debug("Street {} did not have address {}. Creating".format(street.name, addr_id))
                     addr = Address(street=street, number=num, number_end=num2, letter=letter)
                     addr.location = location # location.wkb
+                    #addr.save() # force save address...
                     bulk_addr_list.append(addr)
                     street.addrs[addr_id] = addr
                 else:
+                    addr.location = location # location.wkb
                     if addr._found:
                         self.logger.debug("{}: is duplicate, skipping".format(addr))
                         continue
